# OTOCP

### A MCP server written in python to add, list, complete and delete tasks in Obsidian.

### Tools available:
- add_task - Add tasks based on user input.
- read_tasks - Lists all the task.
- complete_task - Completes a specified task (doesn't have to be exact.)
- clear_tasks - Deletes everything
